==> MarkWiki-1.2.tar.gz: MarkWiki-1.2/markwiki/templates/MarkWiki/Introduction.md <==
Welcome to MarkWiki
===================

> MarkWiki is a wiki that uses **Markdown** to create pages. **Markdown** has
a simple text based approach to define content which you can
[learn very quickly] [syn].

### Why Should I Use MarkWiki?

MarkWiki aims to be dead simple. MarkWiki was born out of frustration
with bad documentation tools behind a company firewall that were too complex.

You should consider MarkWiki if you:

* Need something working fast.
* Are looking for a no fuss answer to how to collaborate with teammates.
* Want to work with Markdown and use some great extra [[MarkWiki/Features]].

### Getting Started

MarkWiki requires just a couple of steps to get going. Fire up the command line
and follow along!

1. Install it.
2. Run the built-in web server.

```bash
$ pip install MarkWiki
$ markwiki
```

The instructions assume you have administrative access to the machine to
install MarkWiki. A great alternative for those without admin access is to use
[virtualenv] [venv].

### Now What?

Once you have the wiki running, you can begin by editing the main page to suit
your needs (don't worry, a copy of the page can be found at
[[MarkWiki/Introduction]] if you ever need to refer back). Or you can select
the `Create a Wiki` link.

Whoever sets up the server should look at [[MarkWiki/Deployment]] for putting
MarkWiki in a production mode. The getting started instructions are primarily
for evaluating MarkWiki.

### License

MarkWiki is and will always be open source software. It is BSD licensed and you
can find the (very short) [license text on GitHub] [lic].

### Releases

Information about past and present releases of MarkWiki is at
[[MarkWiki/Releases]].

[syn]: http://daringfireball.net/projects/markdown/syntax
[venv]: http://www.virtualenv.org/en/latest/
[lic]: https://raw.github.com/mblayman/markwiki/master/LICENSE

==> MarkWiki-1.3.tar.gz: MarkWiki-1.3/markwiki/templates/MarkWiki/Introduction.md <==
Welcome to MarkWiki
===================

> MarkWiki is a wiki that uses **Markdown** to create pages. **Markdown** has
a simple text based approach to define content which you can
[learn very quickly] [syn].

### Why Should I Use MarkWiki?

MarkWiki aims to be dead simple. MarkWiki was born out of frustration
with bad documentation tools behind a company firewall that were too complex.

You should consider MarkWiki if you:

* Need something working fast.
* Are looking for a no fuss answer to how to collaborate with teammates.
* Want to work with Markdown and use some great extra [[MarkWiki/Features]].

### Getting Started

MarkWiki requires just a couple of steps to get going. Fire up the command line
and follow along!

1. Install it.
2. Run the built-in web server.

```bash
$ pip install MarkWiki
$ markwiki
```

The instructions assume you have administrative access to the machine to
install MarkWiki. A great alternative for those without admin access is to use
[virtualenv] [venv].

### Now What?

Once you have the wiki running, you can begin by editing the main page to suit
your needs (don't worry, a copy of the page can be found at
[[MarkWiki/Introduction]] if you ever need to refer back). Or you can select
the `Create a Wiki` link.

Whoever sets up the server should look at [[MarkWiki/Deployment]] for putting
MarkWiki in a production mode. The getting started instructions are primarily
for evaluating MarkWiki.

### License

MarkWiki is and will always be open source software. It is BSD licensed and you
can find the (very short) [license text on GitHub] [lic].

### Releases

Information about past and present releases of MarkWiki is at
[Read the Docs] [rel].

[syn]: http://daringfireball.net/projects/markdown/syntax
[venv]: http://www.virtualenv.org/en/latest/
[lic]: https://raw.github.com/mblayman/markwiki/master/LICENSE
[rel]: https://markwiki.readthedocs.org/en/latest/releases.html
